# gmuse documentation

[![GitHub](https://img.shields.io/badge/GitHub-rvforest%2Fgmuse-blue?logo=github)](https://github.com/rvforest/gmuse)
[![Read the Docs](https://img.shields.io/readthedocs/gmuse)](https://gmuse.readthedocs.io)

[![Checks](https://img.shields.io/github/check-runs/rvforest/gmuse/main)](https://github.com/rvforest/gmuse/actions/workflows/run-checks.yaml?query=branch%3Amain)
[![codecov](https://codecov.io/gh/rvforest/gmuse/graph/badge.svg?token=JXB4LR2241)](https://codecov.io/gh/rvforest/gmuse)

[![PyPI](https://img.shields.io/pypi/v/gmuse.svg)](https://pypi.org/project/gmuse/)
[![Python Versions](https://img.shields.io/pypi/pyversions/gmuse.svg)](https://pypi.org/project/gmuse/)

[![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)

AI generated commit messages.

```{toctree}
:maxdepth: 1
:caption: Getting Started:
:hidden:

getting_started/installation.md
getting_started/quickstart.md

```

```{toctree}
:maxdepth: 1
:caption: User Guide:
:hidden:
```

```{toctree}
:maxdepth: 1
:caption: Reference:
:hidden:

apidocs/index
```

```{toctree}
:maxdepth: 1
:caption: Development:
:hidden:

development/contributing.md
```
